plot_prior_predictive

validation.plot_prior_predictive(result, *, save=None, show=False)

Histogram grid of the prior predictive statistics with observed markers.

Parameters

Name Type Description Default
result PriorPredictiveResult The output of :func:scspill.validation.prior_predictive. required
save str File path to save the figure to. None
show bool Display the figure. False

Returns

Name Type Description
matplotlib.figure.Figure